<?php
namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00009000ParamFaturaModeloContratoFactory
{
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        
        $this->connection = $entityManager->getConnection();
    }
    
   /**
     * A função "insereDadosModContrato" insere os dados de parametização 
     * de fatiuramento na tabela de Modelo de Contrato (FCT_MODELOCONTRATO).
     */
    
    public function insereDadosModContrato($params){
        
        $queryInsereDadosModContr = "UPDATE FCT_MODELOCONTRATO
                                    SET DTINICFATCONTR = :DTINICFATCONTR,
                                        IDQTDIASCOMPCON = :IDQTDIASCOMPCON,
                                        NRQTDIASCOMPCON = :NRQTDIASCOMPCON,
                                        IDTPCOMPETCONT = :IDTPCOMPETCONT,
                                        NRDIACOMPETCONT = :NRDIACOMPETCONT,
                                        IDTPDTEMISSNF = :IDTPDTEMISSNF,
                                        NRDIADTEMISSNF = :NRDIADTEMISSNF,
                                        IDTPDTVENC = :IDTPDTVENC,
                                        NRDIAVENPARCFAT = :NRDIAVENPARCFAT,
                                        IDTPFATUINCOMP = :IDTPFATUINCOMP
                                  WHERE NRSEQMODCONTRA = :NRSEQMODCONTRA
                                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($queryInsereDadosModContr);
        $std->execute($params);
    }

    public function procuraPerfilContrato($params){

        $sql = "SELECT NRPERFILACESSO FROM FCT_RELMODCONTPERFACESS
                 WHERE NRSEQMODCONTRA = :NRSEQMODCONTRA
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $result = $std->fetchAll();
        return $result;
    }

    public function procuraPerfilProposta($params){

        $sql = "SELECT NRPERFILACESSO FROM FCT_RELORCAMODPERFACESS
                 WHERE NRORCAMENTOMODELO = :NRORCAMENTOMODELO
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $result = $std->fetchAll();
        return $result;
    }
    
      /**
     * valida se o Token do Certsign está preenchido
    **/
    public function validaTokenCertsign(array $params) {
        $sql = "SELECT DSTOKENCERTSIGN 
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Busca os signatários padrões de modelo de contrato da parametrização SM 
    **/
    public function buscaSignatariosPadroes(array $params) {
        $sql = "SELECT NRSIGNATARIOSPADR, NRPARCNEGOCIO, IDTIPOASSINATURA, IDTESTEMUNHA, 
                       NRORDENACAO, IDINSERCAOAUTO, NRORG 
                  FROM FCT_SIGNATARIOSPADR
                 WHERE IDINSERCAOAUTO IN ('C','A')
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    
    /**
     * insere os signatários padrões de modelo de contrato que foram buscados na parametrização SM 
    **/
    public function insereSignatariosPadroes(array $params) {
        
        $sql = "INSERT INTO FCT_SIGNATPADRMODCONT (NRSIGNATPADRCONT, NRSEQMODCONTRA, NRPARCNEGOCIO, IDTIPOASSINATURA, IDTESTEMUNHA,
                                                   NRORDENACAO, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, IDATIVO)
                            VALUES (:NRSIGNATPADRCONT, :NRSEQMODCONTRA, :NRPARCNEGOCIO, :IDTIPOASSINATURA, :IDTESTEMUNHA, 
                                    :NRORDENACAO, :NRORG, SYSDATE, :OPERADOR, :NRORG, 'S')";
                             
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function validaSignatCadastrados(array $params) {
        
        $sql = "SELECT COUNT (*) AS VALIDA
                  FROM FCT_SIGNATPADRMODCONT
                 WHERE NRSEQMODCONTRA = :NRSEQMODCONTRA 
                   AND NRPARCNEGOCIO = :NRPARCNEGOCIO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }
}
?>